###############################################################################
# SeemlySmiliesSet.pm                                                         #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
# Written by Zoo, updated to 2.7.00 by D.A. Rorabaugh (Dandello)              #
###############################################################################
use strict;
use warnings;
use CGI qw(:standard);
use CGI::Carp qw(fatalsToBrowser);
use Time::Local;
use File::stat;
our $VERSION = '2.7.00';

our $seemlysmiliessetpmver = 'YaBB 2.7.00 $Revision: 0.9 $';
our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

our (
    $adminurl,         $banned_strings, $buffer,      $cgi_query,
    $date,             $file_buffer,    $filesize,    $header,
    $htmldir,          $mon_num,        $newtemplate,
    $post_speed_count, $size,           $staff,       $string_on,
    $uid,              $use_guardian,   $username,    $vardir,
    $yyhtml_root,      $yymain,         $yymycharset, $yysetlocation,
    $yytitle,          %admin_img,      %admin_txt,   %croak,
    %fatxt,            %FORM,           %INFO,        %maintxt,
    %ssmtxt,           @uploadtranlist,
);

load_language('Admin');
load_language('Mods/Seemly');

my $smiledir = qq~$yyhtml_root/Smilies~;
my $seemlydirs = qq~$htmldir/ModImages/Seemly~;
my $seemlydir  = $smiledir;
my $seemlyurl  = qq~$yyhtml_root/ModImages/Seemly~;
my @days       = ( 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 );
my @days2      = ( 0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335 );
my @smiliename =
  qw(smiley wink cheesy grin angry sad shocked cool huh rolleyes tongue embarassed lipsrsealed undecided kiss cry);
my $smnum = $#smiliename;
my ( $smon, $sday, $sday1, $sname, $other, $i );
my ( $ok, $from, $to, $fromm, $fromd, $tom, $tod, $ssetdir );
my ( @sdir, @seemlysetting, @seemlysetting1 );

sub SeemlySet {
    is_admin();
    $fromm = $INFO{'fm'} || $mon_num;
    $fromd = $INFO{'fd'} || 1;
    $tom   = $INFO{'tm'} || $mon_num;
    $tod   = $INFO{'td'} || $days[ $mon_num - 1 ];
    my $seemlyaction = $INFO{'seemlyaction'} || 'view';
    $ssetdir = $INFO{'ssetdir'} || q{};

####### SeemlyDateCheck
    $ok = 1;
    if    ( $fromm < 1 || $fromm > 12 )                  { $ok = 0; }
    elsif ( $fromd < 1 || $fromd > $days[ $fromm - 1 ] ) { $ok = 0; }
    elsif ( $tom < 1   || $tom > 12 )                    { $ok = 0; }
    elsif ( $tod < 1   || $tod > $days[ $tom - 1 ] )     { $ok = 0; }
    elsif ( $tom < $fromm ) { $tom = $fromm; $tod = $fromd; }
    elsif ( $tom == $fromm && $tod < $fromd ) { $tod = $fromd; }

    if ( !$ok ) {
        $fromm = $mon_num;
        $fromd = 1;
        $tom   = $mon_num;
        $tod   = $days[ $mon_num - 1 ];
    }

    $from = $days2[ $fromm - 1 ] + $fromd - 1;
    $to   = $days2[ $tom - 1 ] + $tod - 1;
####### END SeemlyDateCheck

####### SeemlyRebuild
    is_admin();
    if ( !-e "$vardir/Mods/seemlysmilies.txt" ) {    # no seemlysmilies file
        my $daycount = 0;
        for my $smon ( 1 .. 12 ) {
            if ( $smon < 10 ) { $smon = "0$smon"; }
            for my $sday ( 1 .. $days[ $smon - 1 ] ) {
                $sday1 = $sday;
                if ( $sday < 10 ) { $sday1 = "0$sday"; }
                $seemlysetting[$daycount] = "$smon/$sday1//";
                $daycount++;
            }
        }
        our ($FILE);
        fopen( 'FILE', '>', "$vardir/Mods/seemlysmilies.txt", 1 );
        for my $i ( 0 .. 365 ) {
            print {$FILE} "$seemlysetting[$i]\n"
              or croak "$croak{'print'} Seemly Smiles";
        }
        fclose('FILE');
    }
    else {
        our ($FILE);
        fopen( 'FILE', '<', "$vardir/Mods/seemlysmilies.txt" );
        @seemlysetting = <$FILE>;
        my $seemlycount = @seemlysetting;
        fclose('FILE');
        if ( $seemlycount != 366 ) {    # seemlysmilies record less days of year
            @seemlysetting1 = @seemlysetting;
            my $daycount = 0;
            for my $smon ( 1 .. 12 ) {
                if ( $smon < 10 ) { $smon = "0$smon"; }
                for my $sday ( 1 .. $days[ $smon - 1 ] ) {
                    $sday1 = $sday;
                    if ( $sday < 10 ) { $sday1 = "0$sday"; }
                    $seemlysetting[$daycount] = "$smon/$sday1/";
                    for my $curseemly (@seemlysetting1)
                    {                   # save previous settings
                        chomp $curseemly;
                        my ( $old_smon, $old_sday, $old_sname, $other ) =
                          split /\//xsm, $curseemly;
                        if ( ( $old_smon == $smon ) & ( $old_sday == $sday1 ) )
                        {
                            $seemlysetting[$daycount] =
                              "$seemlysetting[$daycount]$old_sname";
                            last;
                        }
                    }
                    $daycount++;
                }
            }

            if ( -e "$vardir/Mods/seemlysmilies.txt" ) {
                unlink "$vardir/Mods/seemlysmilies.txt";
            }
            fopen( 'FILE', '>', "$vardir/Mods/seemlysmilies.txt", 1 );
            for my $i ( 0 .. 365 ) {
                print {$FILE} "$seemlysetting[$i]/\n"
                  or croak "$croak{'print'} Seemly Smiles";
            }
            fclose('FILE');
        }
    }
####### END SeemlyRebuild

####### SeemlyDirs
    opendir DIR, $seemlydirs or croak "Not found seemlydirs! $seemlydirs";
    my @files = grep { !/^\.\.?$/xsm } readdir DIR;
    closedir DIR;
    my $dircount = 1;
    for my $file (@files) {
        if ( -d "$seemlydirs/$file" ) {
            $ok = 0;
            for my $i ( 0 .. $smnum ) {
                if ( -e "$seemlydirs/$file/$smiliename[$i].gif" ) {
                    $ok = 1;
                    last;
                }
            }
            if ($ok) { $sdir[$dircount] = $file; $dircount++; }
        }
    }
    $sdir[0] = q{          };
    @sdir    = sort @sdir;
    $sdir[0] = $ssmtxt{'4'};
####### END SeemlyDirs

####### SeemlyHead
    my $boxmonths_inner  = q{};
    my $boxmonths_inner2 = q{};
    my $boxdays_inner    = q{};
    my $boxdays_inner2   = q{};
    for my $i ( 1 .. 12 ) {
        my $sel  = q{};
        my $selt = q{};
        if ( $fromm == $i ) {
            $sel = ' selected="selected"';
        }
        $boxmonths_inner .=
            q~      <option value="~
          . sprintf( '%02d', $i )
          . qq~"$sel>$i</option>\n~;

        if ( $tom == $i ) {
            $selt = ' selected="selected"';
        }
        $boxmonths_inner2 .=
            q~      <option value="~
          . sprintf( '%02d', $i )
          . qq~"$selt>$i</option>\n~;
    }
    for my $i ( 1 .. 31 ) {
        my $sel  = q{};
        my $seld = q{};
        if ( $fromd == $i ) {
            $sel = ' selected="selected"';
        }
        if ( $tod == $i ) {
            $seld = ' selected="selected"';
        }
        $boxdays_inner .=
            q~      <option value="~
          . sprintf( '%02d', $i )
          . qq~"$sel>$i</option>\n~;
        $boxdays_inner2 .=
            q~      <option value="~
          . sprintf( '%02d', $i )
          . qq~"$seld>$i</option>\n~;
    }
    $yymain .= qq~
    <div class="rightboxdiv">
    <form action="$adminurl?action=seemlyset2" method="post">
    <table class="bordercolor border-space pad-cell" style="margin-bottom: .5em;">
        <tr>
            <th class="titlebg">&nbsp;<img src="$smiledir/grin.gif"></th>
            <th class="titlebg right" style="width:10%">$ssmtxt{'2'}</th>
            <th class="titlebg center" style="width:auto">
            <label for="fromm"><span class="small">$ssmtxt{'mon'}</span></label>
                <select class="input" name="fromm" id="fromm">
                $boxmonths_inner
                </select> /
                <label for="fromd"><span class="small">$ssmtxt{'day'}</span></label>
                <select class="input" name="fromd" id="fromd">
                    <option value="0">---</option>
                    $boxdays_inner
                </select> $ssmtxt{'to'}
                <label for="tom"><span class="small">$ssmtxt{'mon'}</span></label>
                <select class="input" name="tom" id="tom">
                $boxmonths_inner2
                </select> /
                <label for="tod"><span class="small">$ssmtxt{'day'}</span></label>
                <select class="input" name="tod" id="tod">
                    <option value="0">---</option>
                    $boxdays_inner2
                </select>
            </th>
            <th class="titlebg center" style="width:20%">$ssmtxt{'sets'}:
                <select name='ssetdir'>
                ~;
    for my $i ( 0 .. ( $dircount - 1 ) ) {
        $yymain .= qq~
                    <option value=$i>$sdir[$i]
~;
    }
    $yymain .= qq~
                </select>
            </th>
            <th class="titlebg center" style="width:20%">$ssmtxt{'act'}:
                <select name='saction'>
                    <option value=1>$ssmtxt{'5'}
                    <option value=2>$ssmtxt{'6'}
                    <option value=3>$ssmtxt{'7'}
                    <option value=4>$ssmtxt{'8'}
                    <option value=5>$ssmtxt{'9'}
                </select>
            </th>
            <th class="titlebg center" style="width:15%">
                <input type=submit value=$ssmtxt{'3'}>
            </th>
        </tr>
    </table>
    </form>
~;
####### END SeemlyHead

####### SeemlyView
    my $seemlyact = ucfirst $seemlyaction;
    $seemlyact =~ s/_/\ /gsm;
    $yymain .= qq~
    <table class="bordercolor border-space pad-cell" style="margin-bottom: .5em;">
        <tr>
            <td class="titlebg" colspan="18" style="padding-left:1%">$seemlyact</td>
        </tr>~;
    my $smileout  = q{};
    my $smiliealt = q{};
    if ( $seemlyaction eq 'collections' ) {
        $yymain .= qq~<tr>
        <td class='windowbg2 center' style="width:15%"> <b>$sdir[0]</b> </td>~;
        for my $j ( 0 .. $smnum ) {
            $smileout = "$smiledir/$smiliename[$j].gif";
            $yymain .=
qq~         <td class="windowbg2 center" style="width:5%"><img src='$smileout' alt='$smiliename[$j]'></td>~;
        }
        $yymain .= q~       </tr>~;

        for my $i ( 1 .. ( $dircount - 1 ) ) {
            $yymain .= qq~<tr>
            <td class='windowbg2 center' style="width:15%"> <b>$sdir[$i]</b> </td>~;
            for my $j ( 0 .. $smnum ) {
                if ( !-e "$seemlydirs/$sdir[$i]/$smiliename[$j].gif" ) {
                    $smileout  = "$yyhtml_root/ModImages/nosmilie.gif";
                    $smiliealt = 'NOT FOUND SMILIE! - ';
                }
                else {
                    $smileout  = "$seemlyurl/$sdir[$i]/$smiliename[$j].gif";
                    $smiliealt = q{};
                }
                $yymain .=
qq~          <td class='windowbg2 center' style="width:5%"><img src='$smileout' alt='$smiliealt$smiliename[$j]'></td>~;
            }
            $yymain .= q~       </tr>~;
        }
        $newtemplate ||= q{};
        $yymain .=
qq~<form action="$adminurl?action=seemlyfolder" name="seemlyfolder" method="post" style="display: inline;" accept-charset="$yymycharset">
            <table class="bordercolor border-space pad-cell" style="margin-bottom: .5em;">
                <tr>
                    <th class="titlebg">$admin_img{'prefimg'} $ssmtxt{'modgfolder'}</th>
                </tr><tr>
                    <td class="catbg center">
                        <label for="modfolder"><b>$ssmtxt{'modgfoldername'}</b></label>
                        <input type="text" name="modfolder" value="$newtemplate" size="30" maxlength="50" />
                        <input type="submit" value="$ssmtxt{'save'}" class="button" />
                        <input type="hidden" value="$seemlydirs" name="locus" />
                    </td>
                </tr>
            </table>
        </form>
        <form action="$adminurl?action=seemlyfolderup" name="seemlyfolderup" method="post" style="display: inline;" enctype="multipart/form-data" accept-charset="$yymycharset">
            <table class="bordercolor border-space pad-cell">
                <tr>
                    <th class="titlebg" colspan="2">$admin_img{'prefimg'} $ssmtxt{'modgfolderup'}</th>
                </tr><tr>
                    <td class="catbg right">
                        <label for="modfolderfolder"><b>$ssmtxt{'modfolderfolder'}</b></label>
                    </td><td class="catbg">
                        <select name="modfolderfolder"><option value="">--</option>
~;
        opendir TMPLGDIR, "$seemlydirs";
        my @newtemplates = readdir TMPLGDIR;
        closedir TMPLGDIR;
        my $templs     = q{};
        my $newgtempls = q{};

        for my $name ( sort @newtemplates ) {
            if ( $name ne q{.} && $name ne q{..} && $name !~ m/[.]/sm ) {
                $newgtempls .=
qq~                         <option value="$name">$name</option>
~;
            }
        }
        $yymain .= qq~$newgtempls               </select>
                    </td>
                </tr><tr>
                    <td class="catbg right">
                        <label for="newtemfiles"><b>$ssmtxt{'modfolderup2'}</b></label>
                    </td><td class="catbg">
                        <input type="file" name="newtemfiles" id="newtemfiles" size="35" />
                    </td>
                </tr><tr>
                    <td class="catbg center" colspan="2">
                        <input type="submit" value="$ssmtxt{'save'}" class="button" />
                    </td>
                </tr>
            </table>
        </form>~;
    }
    else {
        if ( $seemlyaction eq 'dayset' ) {
            my @seemlysetting2 = @seemlysetting;
            for my $i ( $from .. $to ) {
                ( $smon, $sday, $sname, $other ) = split /\//xsm,
                  $seemlysetting[$i], 4;
                if   ( !$ssetdir || $ssetdir == 0 ) { $sname = q{}; }
                else                   { $sname = $sdir[$ssetdir]; }
                $seemlysetting[$i] = "$smon/$sday/$sname/\n";
            }
            if ( -e "$vardir/Mods/seemlysmilies.txt" ) {
                unlink "$vardir/Mods/seemlysmilies.txt";
            }
            our ($FILE);
            fopen( 'FILE', '>', "$vardir/Mods/seemlysmilies.txt", 1 );
            for my $i ( 0 .. 365 ) {
                print {$FILE} "$seemlysetting[$i]"
                  or croak "$croak{'print'} Seemly Smiles";
            }
            fclose('FILE');
        }
        my ( @sday, @smon, @sname );
        for my $i ( $from .. $to ) {
            ( $smon[$i], $sday[$i], $sname[$i], $other ) =
              split /\//xsm, $seemlysetting[$i], 4;
            my $smset = 'default';
            if ( $sname[$i] ne q{} ) {
                $seemlydir = "$seemlyurl/$sname[$i]";
                $smset     = "$sname[$i]";
            }
            else { $seemlydir = $smiledir; }

            if ( $seemlyaction eq 'view' || $seemlyaction eq 'dayset' ) {
                $yymain .= qq~
        <tr>
            <td class='windowbg2 center' style="width:4%"> $smon[$i]/$sday[$i] </td>
            <td class='windowbg2 center' style="width:11%"> <b>$smset</b> </td> ~;
                for my $j ( 0 .. $smnum ) {
                    if ( $sname[$i] ne q{} ) {
                        if ( !-e "$seemlydirs/$sname[$i]/$smiliename[$j].gif" )
                        {
                            $smileout  = "$yyhtml_root/ModImages/nosmilie.gif";
                            $smiliealt = "NOT FOUND SMILIE! $sname[$i]/";
                        }
                        else {
                            $smileout  = "$seemlydir/$smiliename[$j].gif";
                            $smiliealt = q{};
                        }
                    }
                    else {
                        $smileout  = "$seemlydir/$smiliename[$j].gif";
                        $smiliealt = $ssmtxt{'4'};
                    }
                    $yymain .=
qq~             <td class='windowbg2 center' style="width:5%"><img src='$smileout' alt='$smiliealt$smiliename[$j]'></td>~;
                }
                $yymain .= q~</tr>~;
            }
            elsif ( $seemlyaction eq 'view_set_days' ) {
                if ( $sname[$i] ne q{} ) {
                    $yymain .= qq~
            <tr>
                <td class='windowbg2 center' style="width:4%"> $smon[$i]/$sday[$i] </td>
                <td class='windowbg2 center' style="width:11"> <b>$sname[$i]</b> </td>~;
                    for my $j ( 0 .. $smnum ) {
                        if ( !-e "$seemlydirs/$sname[$i]/$smiliename[$j].gif" )
                        {
                            $smileout  = "$yyhtml_root/ModImages/nosmilie.gif";
                            $smiliealt = "NOT FOUND SMILIE! $sname[$i]/";
                        }
                        else {
                            $smileout  = "$seemlydir/$smiliename[$j].gif";
                            $smiliealt = q{};
                        }
                        $yymain .=
qq~<td class='windowbg2 center' style="width:5%"><img src='$smileout' alt='$smiliealt$smiliename[$j]'></td>~;
                    }
                    $yymain .= q~</tr>~;
                }
            }
            elsif ( $seemlyaction eq 'error' ) {
                if ( $sname[$i] ne q{} ) {
                    my $founderror = 0;
                    for my $j ( 0 .. $smnum ) {
                        if ( !-e "$seemlydirs/$sname[$i]/$smiliename[$j].gif" )
                        {
                            $founderror = 1;
                            last;
                        }
                    }
                    if ( $founderror == 1 ) {
                        $yymain .= qq~<tr>
            <td class='windowbg2 center' style="width:4%"> $smon[$i]/$sday[$i] </td>
              <td class='windowbg2 center' style="width:11%"> <b>$sname[$i]</b> </td>~;
                        for my $j ( 0 .. $smnum ) {
                            if (
                                !-e "$seemlydirs/$sname[$i]/$smiliename[$j].gif"
                              )
                            {
                                $smileout =
                                  "$yyhtml_root/ModImages/nosmilie.gif";
                                $smiliealt = "NOT FOUND SMILIE! $sname[$i]/";
                            }
                            else {
                                $smileout  = "$seemlydir/$smiliename[$j].gif";
                                $smiliealt = q{};
                            }
                            $yymain .=
qq~<td class='windowbg2 center' style="width:4%"'><img src='$smileout' alt='$smiliealt$smiliename[$j]'></td>~;
                        }
                        $yymain .= q~</tr>~;
                    }
                }
            }
        }
    }
    $yymain .= q~
    </table>
    </div>
    ~;
####### END SeemlyView

    $yytitle = $ssmtxt{'1'};
    admintemplate();
    exit;
}

sub SeemlySet2 {
    is_admin();
    $fromm = $FORM{'fromm'};
    $fromd = $FORM{'fromd'};
    $tom   = $FORM{'tom'};
    $tod   = $FORM{'tod'};
    my $saction = $FORM{'saction'};
    $ssetdir = $FORM{'ssetdir'};

####### SeemlyDateCheck
    $ok = 1;
    if    ( $fromm < 1 || $fromm > 12 )                  { $ok = 0; }
    elsif ( $fromd < 1 || $fromd > $days[ $fromm - 1 ] ) { $ok = 0; }
    elsif ( $tom < 1   || $tom > 12 )                    { $ok = 0; }
    elsif ( $tod < 1   || $tod > $days[ $tom - 1 ] )     { $ok = 0; }
    elsif ( $tom < $fromm ) { $tom = $fromm; $tod = $fromd; }
    elsif ( $tom == $fromm && $tod < $fromd ) { $tod = $fromd; }

    if ( !$ok ) {
        $fromm = $mon_num;
        $fromd = 1;
        $tom   = $mon_num;
        $tod   = $days[ $mon_num - 1 ];
    }

    $from = $days2[ $fromm - 1 ] + $fromd - 1;
    $to   = $days2[ $tom - 1 ] + $tod - 1;
####### END SeemlyDateCheck

    $yysetlocation =
"$adminurl?action=seemlyset;fm=$fromm;fd=$fromd;tm=$tom;td=$tod;seemlyaction=view";
    if ( $saction == 2 ) {
        $yysetlocation =
"$adminurl?action=seemlyset;fm=$fromm;fd=$fromd;tm=$tom;td=$tod;seemlyaction=view_set_days";
    }
    elsif ( $saction == 3 ) {
        $yysetlocation =
"$adminurl?action=seemlyset;fm=$fromm;fd=$fromd;tm=$tom;td=$tod;seemlyaction=collections";
    }
    elsif ( $ok && $saction == 4 ) {
        $yysetlocation =
"$adminurl?action=seemlyset;fm=$fromm;fd=$fromd;tm=$tom;td=$tod;seemlyaction=dayset;ssetdir=$ssetdir";
    }
    elsif ( $saction == 5 ) {
        $yysetlocation =
          "$adminurl?action=seemlyset;fm=1;fd=1;tm=12;td=31;seemlyaction=error";
    }
    redirectexit();
    return;
}

sub NewSmilieFolder {
    if ( $FORM{'modfolder'} ) {
        my $newfolder = $FORM{'modfolder'};
        my $newd      = $FORM{'locus'};
        my $newdir    = qq~$newd/$newfolder~;
        mkdir $newdir, 0755;
        $yysetlocation =
          qq~$adminurl?action=seemlyset;seemlyaction=collections~;
        redirectexit();
    }
    else { fatal_error('nofolder'); }

    return;
}

sub NewSmilieFolder2 {
    if ( $INFO{'newfolder'} ) {
        my $newfolder = $INFO{'newfolder'};
        if ( -d $newfolder ) {
            $yymain = qq~
<div class="bordercolor rightboxdiv">
<table class="border-space pad-cell" style="margin-bottom: .5em;">
    <tr>
        <th class="titlebg">$admin_img{'prefimg'} $admin_txt{'newfolder'}</th>
    </tr><tr class="windowbg2 vtop bold">
        <td>$newfolder $admin_txt{'foldercreated'}</td>
    </tr>
</table>
</div>
<div style="width: 100%; text-align: center;"><a href="javascript:history.go(-1);">$maintxt{'193'}</a></div>
~;
            $yytitle = qq~$admin_txt{'newfolder'} $admin_txt{'foldercreated'}~;
            admintemplate();
            exit;
        }
        else {
            $yymain = qq~
<div class="bordercolor rightboxdiv">
<table class="border-space pad-cell" style="margin-bottom: .5em;">
    <tr>
        <th class="titlebg">$admin_img{'prefimg'} $admin_txt{'newfolder'}</th>
    </tr><tr class="windowbg2 vtop bold">
        <td>$newfolder $admin_txt{'foldernotcreated'}</td>
    </tr>
</table>
</div>
<div style="width: 100%; text-align: center;"><a href="javascript:history.go(-1);">$maintxt{'193'}</a></div>
~;
            $yytitle = qq~$admin_txt{'newfolder'} Error~;
            admintemplate();
            exit;
        }
    }
    else {
        $yysetlocation =
          qq~$adminurl?action=seemlyset;seemlyaction=collections~;
        redirectexit();
    }
    return;
}

sub NewSmiliesUpload {
    is_admin_or_gmod();

    my $uploadto  = $FORM{'modfolderfolder'};
    my $newfolder = qq~$htmldir/ModImages/Seemly/$uploadto~;
    my $newups    = $FORM{'newtemfiles'};
    $FORM{'newtemfiles'} =
      UploadFile2( 'newtemfiles', $uploadto, 'gif', '250', '0', '0' );
    my $uplabel = $admin_txt{'uploadedg'};

    $yymain = qq~
<div class="bordercolor rightboxdiv">
<table class="border-space pad-cell" style="margin-bottom: .5em;">
    <tr>
        <th class="titlebg">$admin_img{'prefimg'} $uplabel</th>
    </tr><tr class="windowbg2 vtop bold">
        <td>Uploaded to $newfolder: $newups</td>
    </tr>
</table>
</div>
<div style="width: 100%; text-align: center;"><a href="javascript:history.go(-1);">$maintxt{'193'}</a></div>
~;
    $yytitle = 'New Seemly Smiley Uploads';
    admintemplate();
    exit;
}

sub UploadFile2 {
    my (
        $file_upload, $uploadto,        $file_extensions,
        $file_size,   $directory_limit, $loc
    ) = @_;
    my $myfiledir      = $uploadto;
    my $file_directory = qq~$htmldir/ModImages/Seemly/$uploadto~;

    load_language('FA');
    require Sources::SpamCheck;

    my $file    = q{};
    my $fixfile = q{};
    if ($cgi_query) { $file = $cgi_query->upload($file_upload); }
    if ($file) {
        $fixfile = $file;
        $fixfile =~ s/.+\\([^\\]+)$|.+\/([^\/]+)$/$1/xsm;
        if ( $fixfile =~ /[^\w+\-.:]/xsm ) {
            my %translist = loadtranlist();
            @uploadtranlist = keys %translist;
            for (@uploadtranlist) {
                $fixfile =~ s/$_/$translist{$_}/gxsm;
            }
            $fixfile =~ s/[^\w+\-.:]/_/gxsm;
        }

        # replace . with _ in the filename except for the extension
        my $fixname = $fixfile;
        my $fixext  = q{};
        if ( $fixname =~ s/(.+)([.].+?)$/$1/xsm ) {
            $fixext = $2;
        }

        my $spamdetected = spamcheck($fixname);
        if ( !$staff ) {
            if ($spamdetected) {
                ${ $uid . $username }{'spamcount'}++;
                ${ $uid . $username }{'spamtime'} = $date;
                user_account( $username, 'update' );
                my $spam_hits_left_count =
                  $post_speed_count - ${ $uid . $username }{'spamcount'};
                unlink "$file_directory/$fixfile";
                fatal_error('tsc_alert');
            }
        }
        if ( $use_guardian && $string_on ) {
            my @bannedstrings = split /[|]/xsm, $banned_strings;
            for (@bannedstrings) {
                chomp;
                if ( $fixname =~ m/$_/ixsm ) {
                    fatal_error( 'attach_name_blocked', "($_)" );
                }
            }
        }

        $fixext =~ s/[.](pl|pm|cgi|php)/._$1/ixsm;
        $fixname =~ s/[.](?!tar$)/_/gxsm;
        $fixfile = qq~$fixname$fixext~;
        if ( $fixfile eq 'default.html' ) { $fixfile = qq~$myfiledir.html~ }
        if ( $fixfile eq 'index.html' || $fixfile eq '.htaccess' ) {
            fatal_error('attach_file_blocked');
        }
        $fixfile = check_existence( $file_directory, $fixfile );

        my $match = 0;
        for my $ext ( split /[|]/xsm, $file_extensions ) {
            if ( grep { /$ext$/ixsm } $fixfile ) {
                $match = 1;
                last;
            }
        }

        if ( !$match ) {
            unlink "$file_directory/$fixfile";
            fatal_error( q{}, "$fixfile $fatxt{'20'} $file_extensions" );
        }

        while ( $size = read $file, $buffer, 512 ) {
            $filesize += $size;
            $file_buffer .= $buffer;
        }
        if ( $file_size && $filesize > ( 1024 * $file_size ) ) {
            unlink "$file_directory/$fixfile";
            fatal_error( q{},
                    "$fatxt{'21'} $fixfile ("
                  . int( $filesize / 1024 )
                  . " KB) $fatxt{'21b'} "
                  . $file_size );
        }
        if ($directory_limit) {
            my $dirsize = dirsize($file_directory);
            if ( $file_size > ( ( 1024 * $directory_limit ) - $dirsize ) ) {
                unlink "$file_directory/$fixfile";
                fatal_error(
                    q{},
                    "$fatxt{'22'} $fixfile ("
                      . (
                        int( $file_size / 1024 ) -
                          $directory_limit +
                          int( $dirsize / 1024 )
                      )
                      . " KB) $fatxt{'22b'}"
                );
            }
        }

 # create a new file on the server using the formatted ( new instance ) filename
        our ($NEWFILE);
        if ( fopen( 'NEWFILE', '>', "$file_directory/$fixfile" ) ) {
            binmode $NEWFILE;

            # needed for operating systems (OS) Windows, ignored by Linux
            print {$NEWFILE} $file_buffer
              or croak "$croak{'print'} NEWFILE";    # write new file on HD
            fclose('NEWFILE') or croak "$croak{'open'} NEWFILE";
        }
        else
        { # return the server's error message if the new file could not be created
            unlink "$file_directory/$fixfile";
            fatal_error( 'file_not_open', "$file_directory" );
        }
        my (%filesizekb);

     # check if file has actually been uploaded, by checking the file has a size
        $filesizekb{$fixfile} = -s "$file_directory/$fixfile";
        if ( !$filesizekb{$fixfile} ) {
            unlink "$file_directory/$fixfile";
            fatal_error( 'file_not_uploaded', $fixfile );
        }
        $filesizekb{$fixfile} = int( $filesizekb{$fixfile} / 1024 );

        if ( $fixfile =~ /[.](jpe?g|gif|png)$/ixsm ) {
            my $okatt = 1;
            if ( $fixfile =~ /gif$/ixsm ) {
                our ($ATTFILE);
                fopen( 'ATTFILE', '<', "$file_directory/$fixfile" )
                  or croak "$croak{'open'} ATTFILE";
                read $ATTFILE, $header, 10;
                my ( $giftest, undef, undef, undef, undef, undef ) =
                  unpack 'a3a3C4', $header;
                fclose('ATTFILE') or croak "$croak{'close'} ATTFILE";
                if ( $giftest ne 'GIF' ) { $okatt = 0; }
            }
            our ($ATTFILE);
            fopen( 'ATTFILE', '<', "$file_directory/$fixfile" )
              or croak "$croak{'open'} ATTFILE";
            while ( read $ATTFILE, $buffer, 1024 ) {
                if ( $buffer =~ /<(html|script|body)/igxsm ) {
                    $okatt = 0;
                    last;
                }
            }
            fclose('ATTFILE') or croak "$croak{'close'} ATTFILE";
            if ( !$okatt ) {    # delete the file as it contains illegal code
                unlink "$file_directory/$fixfile";
                fatal_error( 'file_not_uploaded', "$fixfile $fatxt{'20a'}" );
            }
        }
    }
    return ($fixfile);
}

1;
